# Music Audio Feature Extractor

## `mafe_scan.py`

```bash
$ mafe_scan.py --help
Usage: mafe_scan.py [OPTIONS]

Options:
  -f, --base-folders TEXT  Directory to scan  [required]
  -p, --parallel           Use parallel execution
  -q, --quiet              Suppress warnings and progress messages
  --help                   Show this message and exit.
```